==> open-xchange-gui_6.22.0.orig.tar.bz2: open-xchange-gui-6.22.0/plugins/com.openexchange.secret.recovery/register.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 * 
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * 
 * Copyright (C) Open-Xchange Inc., 2006-2012
 * Mail: info@open-xchange.com 
 * 
 * @author Francisco Laguna <francisco.laguna@open-xchange.com>
 * 
 */

setTimeout(function(){
	checkForPasswordChange();
},3000);

/**
 * function checkForPasswordChange()
 * checks if user-password was changed. If so, all subscriptions
 * will be broken and old password is needed once to decrypt 
 * subscription-credentials on backend.
 */

function checkForPasswordChange(){

	// successhandler for initial request
	var successHandler = function(e){
		if (e.data) {
			if (e.data.secretWorks == false){
				
				// workaround to assure the alert-window stays open
				// when clicking on OK
				globalalert.leaveOpen = true;
				
				// on-ok function
				var onOk = function() {
					// get enterd password
					var oldPass = jQuery("#oldKeywordField").val();
					if (oldPass !== "") {
						var migrateSuccess = function(e,f){
							if (e.data == 1){
								// returned 1 so decryption of subscriptions on backend
								// was successfull
								delete (globalalert.leaveOpen);
								jQuery("#oldPasswordWarn").empty();
								jQuery("#oldPasswordWarn").fadeIn("<b>" + _("Subscriptions successfully migrated")+"</b>","slow");
								setTimeout(function(){AlertPopup.close();},1000);
							}else{
								// error, the old password was wrong
								jQuery("#oldPasswordWarn").empty();
								jQuery("#oldPasswordWarn").append("<b>" + _("Old Password is wrong.")+"</b>");
								
							}
							
						};
						
						// second request to migrate subscriptions from old to new password
						jQuery.ajax({
						     type: "POST",
					         url: AjaxRoot + "/recovery/secret?action=migrate&session="+session,
					         data: { password: oldPass },
					         success: migrateSuccess,
					         error: function(XMLHttpRequest, textStatus, errorThrown) {
    							 triggerEvent("OX_New_Error", 2,
    					                //#. HTTP Errors from the server
    					                //#. %1$s is the numeric HTTP status code
    					                //#. %2$s is the corresponding HTTP status text
    								    //#, c-format
    					                format(_("Error: %1$s - %2$s"), textStatus, errorThrown));
							 },
					         dataType: "json"
					     });
					}else{
						// field was emtpy, display error
						jQuery("#oldPasswordWarn").empty();
						jQuery("#oldPasswordWarn").append("<b>" + _("Field may not be empty")+"</b>");
					}
				};
				
				// create new alert window without text with ok and cancel
				// button
				newConfirm(_("Password has changed"),"", 3, onOk);
				
				jQuery("#oldPasswordWarn").empty(); 
				
				// Fill alertwindow manualy with text
				jQuery("#alert_window_text").append(
					jQuery("<div>").append(
						_("Your password changed. For a future use of your subscriptions and additional E-Mail accounts enter your old password. This only has to be done once. If you now cancel the action you have to newly set up all subscriptions and additional E-Mail accounts.") + "<br>"	
					  ).append(
						'<p style="text-align:center"><label for="keyword">'+ _("Your old password") + '</label>'+
						'&nbsp;<input name="keyword" id="oldKeywordField" type="password" size="16">'+
						'</p><div id="oldPasswordWarn" style="text-align:center"><br></div>')
				);
				
				centerPopupWindow(jQuery("#alert_window"));
				jQuery("#alert_window").css({"display":"block"});
				
			}
		}
	};
  
    jQuery.ajax({

         url: AjaxRoot + "/recovery/secret?action=check&session="+session,
         success: successHandler,
         error: function(XMLHttpRequest, textStatus, errorThrown){
		
		triggerEvent("OX_New_Error", 2,
               //#. HTTP Errors from the server
               //#. %1$s is the numeric HTTP status code
               //#. %2$s is the corresponding HTTP status text
			    //#, c-format
               format(_("Error: %1$s - %2$s"), textStatus, errorThrown));
		 },
         dataType: "json",
         type:"get"
     });
}

==> open-xchange-gui_6.22.11.orig.tar.bz2: open-xchange-gui-6.22.11/plugins/com.openexchange.secret.recovery/register.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 * 
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * 
 * Copyright (C) Open-Xchange Inc., 2006-2012
 * Mail: info@open-xchange.com 
 * 
 * @author Francisco Laguna <francisco.laguna@open-xchange.com>
 * 
 */

setTimeout(function(){
	checkForPasswordChange();
},3000);

/**
 * function checkForPasswordChange()
 * checks if user-password was changed. If so, all subscriptions
 * will be broken and old password is needed once to decrypt 
 * subscription-credentials on backend.
 */

function checkForPasswordChange(){

	// successhandler for initial request
	var successHandler = function(e){
		if (e.data) {
			if (e.data.secretWorks == false){
				
				// workaround to assure the alert-window stays open
				// when clicking on OK
				globalalert.leaveOpen = true;
				
				var finalCb = function (action, oldPass) {
					var migrateSuccess = function (e,f) {
						if (action === "clean_up" || e.data == 1){
							// returned 1 so decryption of subscriptions on backend
							// was successfull
							delete (globalalert.leaveOpen);
							jQuery("#oldPasswordWarn").empty();
							var msg = _("Subscriptions successfully migrated");
							if (action === "clean_up") {
								msg = _("Subscriptions successfully reset. Please keep in mind you have to newly set up all subscriptions and additional E-Mail accounts.");
							}
							jQuery("#oldPasswordWarn").fadeIn("<b>" + msg + "</b>","slow");
							setTimeout(function(){ AlertPopup.close(); }, 1000);
						} else {
							// error, the old password was wrong
							jQuery("#oldPasswordWarn").empty();
							jQuery("#oldPasswordWarn").append("<b>" + _("Old Password is wrong.")+"</b>");
						}
					};
					
					var data = {
						type: "POST",
						url: AjaxRoot + "/recovery/secret?action=" + action + "&session="+session,
						data: { password: oldPass },
						success: migrateSuccess,
						error: function(XMLHttpRequest, textStatus, errorThrown) {
							triggerEvent("OX_New_Error", 2,
			                //#. HTTP Errors from the server
			                //#. %1$s is the numeric HTTP status code
			                //#. %2$s is the corresponding HTTP status text
						    //#, c-format
			                format(_("Error: %1$s - %2$s"), textStatus, errorThrown));
						},
						dataType: "json"
					};
					// reset, no data required
					if (action === "clean_up") {
						delete(data.data);
					}
					jQuery.ajax(data);
				};
				
				// on-ok function
				var onOk = function() {
					// get enterd password
					var oldPass = jQuery("#oldKeywordField").val();
					if (oldPass !== "") {
						finalCb("migrate", oldPass);
					} else {
						// field was emtpy, display error
						jQuery("#oldPasswordWarn").empty();
						jQuery("#oldPasswordWarn").append("<b>" + _("Field may not be empty")+"</b>");
					}
				};
				
				// create new alert window without text with ok and cancel
				// button
				newConfirm(_("Password has changed"),"", 3, onOk, function() {
					finalCb("clean_up", null);
				});
				
				jQuery("#oldPasswordWarn").empty(); 
				
				// Fill alertwindow manualy with text
				jQuery("#alert_window_text").append(
					jQuery("<div>").append(
						_("Your password changed. For a future use of your subscriptions and additional E-Mail accounts enter your old password. This only has to be done once. If you now cancel the action you have to newly set up all subscriptions and additional E-Mail accounts.") + "<br>"	
					  ).append(
						'<p style="text-align:center"><label for="keyword">'+ _("Your old password") + '</label>'+
						'&nbsp;<input name="keyword" id="oldKeywordField" type="password" size="16">'+
						'</p><div id="oldPasswordWarn" style="text-align:center"><br></div>')
				);
				
				centerPopupWindow(jQuery("#alert_window"));
				jQuery("#alert_window").css({"display":"block"});
				
			}
		}
	};
  
    jQuery.ajax({

         url: AjaxRoot + "/recovery/secret?action=check&session="+session,
         success: successHandler,
         error: function(XMLHttpRequest, textStatus, errorThrown){
		
		triggerEvent("OX_New_Error", 2,
               //#. HTTP Errors from the server
               //#. %1$s is the numeric HTTP status code
               //#. %2$s is the corresponding HTTP status text
			    //#, c-format
               format(_("Error: %1$s - %2$s"), textStatus, errorThrown));
		 },
         dataType: "json",
         type:"get"
     });
}
